@@ -6,30 +6,42 @@ use Config;
 use base qw( Alien::Base );
 
 # ABSTRACT: Build and make available libffi
-our $VERSION = '0.06_05'; # VERSION
+our $VERSION = '0.15_01'; # TRIAL VERSION
 
-if($^O eq 'openbsd')
+sub libs
 {
+  my $class = shift;
+  
+  my $libs = $class->SUPER::libs(@_);
 
-  *libs = sub
+  if($^O eq 'openbsd' && !$Config{usethreads} && Alien::FFI->install_type eq 'share')
   {
-    shift->SUPER::libs(@_) . (
-         $^O eq 'openbsd'
-      && !$Config{usethreads} 
-      && Alien::FFI->install_type eq 'share' 
-      ? ' /usr/lib/libpthread.a' : '');
+    $libs .= ' /usr/lib/libpthread.a';
   }
-}
-
-if($^O eq 'MSWin32' && $Config{cc} =~ /cl(\.exe)?$/i)
-{
-  *libs = sub
+  
+  if($^O eq 'MSWin32' && $Config{ccname} eq 'cl')
   {
-    my $libs = shift->SUPER::libs(@_);
     $libs =~ s{-L}{/LIBPATH:}g;
     $libs =~ s{-l([A-Za-z]+)}{$1.LIB}g;
-    $libs;
   }
+  
+  $libs;
+}
+
+sub cflags
+{
+  my $class = shift;
+  
+  my $cflags = $class->SUPER::cflags(@_);
+  
+  if($class->install_type eq 'share'
+  && $^O eq 'MSWin32'
+  && $Config{ccname} eq 'cl')
+  {
+    $cflags .= " -DFFI_BUILDING";
+  }  
+  
+  $cflags;
 }
 
 
@@ -47,7 +59,7 @@ Alien::FFI - Build and make available libffi
 
 =head1 VERSION
 
-version 0.06_05
+version 0.15_01
 
 =head1 SYNOPSIS
 
